.. spdcalc-py documentation master file, created by
   sphinx-quickstart on Thu Aug 29 14:45:15 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to spdcalc-py's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   spdcalc

.. automodule:: spdcalc
   :members:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
